@@ -1,4 +1,4 @@
-/* Time-stamp: <2006-05-21 04:16:59 poser> */
+/* Time-stamp: <2006-10-09 10:57:12 poser> */
 
 /*
  * Copyright (C) 1993-2006 William J. Poser (billposer@alum.mit.edu).
@@ -40,6 +40,7 @@ PrintGeneralFlags(FILE *fp)
   fprintf(fp,_("\t-v,--version\t\tPrint version message\n"));
   fprintf(fp,_("\t-D,--defaults\t\tList defaults\n"));
   fprintf(fp,_("\t-F,--general-options\tList general command line flags\n"));
+  fprintf(fp,_("\t-G,--gnu-equivalences\tList GNU equivalences\n"));
   fprintf(fp,_("\t-K,--key-specific-options\n\t\t\t\tList key-specific command line flags\n"));
   fprintf(fp,_("\t-L,--limits\t\tList limits\n"));
   fputc('\n',fp);
@@ -105,6 +106,22 @@ void PrintKeySpecificFlags(FILE *fp)
   fputc('\n',fp);				
 }
 
+void
+PrintGNUEquivalences(FILE *fp)
+{
+  fprintf(fp,"GNU sort\t\t\t\tmsort\n");
+  fprintf(fp,"-c,--check\t\t\t\t-Q,--check-only\n");
+  fprintf(fp,"-f,--ignore-case\t\t\t-C,--fold-case\n");
+  fprintf(fp,"-g,--general-numeric-sort\t\t-c n,--comparison-type n\n");
+  fprintf(fp,"-M,--month-sort\t\t\t\t-c m,--comparison-type m\n");
+  fprintf(fp,"-n,--numeric-sort\t\t\t-c N,--comparison-type N\n");
+  fprintf(fp,"-r,--reverse\t\t\t\t-i,--invert-locally\n");
+  fprintf(fp,"-s,--stable\t\t\t\t-a I,--algorithm I\n");
+  fprintf(fp,"           \t\t\t\t-a M,--algorithm M\n");
+  fprintf(fp,"-t <fs>,--field-separator <fs>\t\t-d <fs>,--field-separators <fs>\n");
+  fprintf(fp,"-z,--zero-terminated\t\t\t-r \\000,--record-separator \\000\n");
+  fputc('\n',fp);				
+}
 #else
 
 void
@@ -115,6 +132,7 @@ PrintGeneralFlags(FILE *fp)
   fprintf(fp,_("\t-v                    Print version message\n"));
   fprintf(fp,_("\t-D                    List defaults\n"));
   fprintf(fp,_("\t-F                    List general command line flags\n"));
+  fprintf(fp,_("\t-G                    List GNU equivalences\n"));
   fprintf(fp,_("\t-K                    List key-specific command line flags\n"));
   fprintf(fp,_("\t-L                    List limits\n"));
   fputc('\n',fp);
@@ -178,6 +196,23 @@ PrintKeySpecificFlags(FILE *fp)
   fputc('\n',fp);				
 }
 
+void
+PrintGNUEquivalences(FILE *fp)
+{
+  fprintf(fp,"GNU sort\t\t\t\tmsort\n");
+  fprintf(fp,"-c,--check\t\t\t\t-Q\n");
+  fprintf(fp,"-f,--ignore-case\t\t\t-C\n");
+  fprintf(fp,"-g,--general-numeric-sort\t\t-c n\n");
+  fprintf(fp,"-M,--month-sort\t\t\t\t-c m\n");
+  fprintf(fp,"-n,--numeric-sort\t\t\t-c N\n");
+  fprintf(fp,"-r,--reverse\t\t\t\t-i\n");
+  fprintf(fp,"-s,--stable\t\t\t\t-a I\n");
+  fprintf(fp,"           \t\t\t\t-a M\n");
+  fprintf(fp,"-t <fs>,--field-separator <fs>\t\t-d <fs>\n");
+  fprintf(fp,"-z,--zero-terminated\t\t\t-r \\000\n");
+  fputc('\n',fp);				
+}
+
 #endif
 void
 PrintDefaults(FILE *fp)
@@ -195,6 +230,7 @@ PrintDefaults(FILE *fp)
    fprintf(fp,_("    Date format                     y-m-d (International Date Format)\n"));
    fprintf(fp,_("    Sort order                      numerical Unicode order\n"));
    fprintf(fp,_("    Sort type                       lexicographic\n"));
+   fprintf(fp,_("    Algorithm                       quicksort\n"));
    fprintf(fp,"\n");
 }
 
