@@ -206,19 +206,19 @@ ugetline(FILE *fp,wchar_t *buf, int size)
   }
   GetLineDone = 1;
   switch (c){ 
-     case NOTENOUGHBYTES:
+     case UTF8_NOTENOUGHBYTES:
        fprintf(stderr,"Truncated UTF-8 sequence encountered.\n");
        exit(1);
        break;
-     case BADINCODE:
+     case UTF8_BADINCODE:
        fprintf(stderr,"Invalid UTF-8 code encountered.\n");
        exit(1);
        break;
-     case BADOUTCODE:
+     case UTF8_BADOUTCODE:
        fprintf(stderr,"Encountered invalid Unicode.\n");
        exit(1);
        break;
-     case IOERROR:
+     case UTF8_IOERROR:
        snprintf(msg,MSGSIZE-1,"Error reading input.\n");
        perror(msg);
        exit(1);
