@@ -207,7 +207,7 @@ int u82u32 (UTF8 *s, wchar_t **t,wchar_t *maxptr) {
     BytesNeeded = (int) TrailingBytesForUTF8[*s];
     if(!isLegalUTF8P(cptr,BytesNeeded+1)){
       fprintf(stderr,"u82u32: invalid UTF-8 input at byte %d.\n",(cptr-s0)+1);
-      return(BADINCODE);
+      return(UTF8_BADINCODE);
     }
     ch = 0;
     switch (BytesNeeded) {
