@@ -1,4 +1,7 @@
 
+#include "config.h"
+#include "compdefs.h"
+
 #include <stdio.h>
 #include <stddef.h>
 #include <wchar.h>
